@@ -872,12 +872,16 @@ Log::Log4perl::Config::PropertyConfigurator
 
 Log::Log4perl::Config::LDAPConfigurator (coming soon!)
 
-=head1 AUTHOR
-
-Kevin Goess, <cpan@goess.org> Jan-2003
-
 The code is brazenly modeled on log4j's DOMConfigurator class, (by 
 Christopher Taylor, Ceki Gülcü, and Anders Kristensen) and any
 perceived similarity is not coincidental.
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
+
 =cut
